@@ -4,8 +4,11 @@
 
       WRITE(*,*) '*** TEST FOR MEASURING RUNTIME'
       CALL CLCKST
+      ISEED=1
+      X=RNGU1(ISEED)
       DO 10 I=1,10000000
-        SX=SIN(REAL(I))
+        X=RNGU1(ISEED)
+        SX=SIN(X)
    10 CONTINUE
       CALL CLCKGT(TIME)
       CALL CLCKDT(DT0)
