@@ -104,7 +104,7 @@ void zxdopn_(width, height, iposx, iposy,
 
     fscanf (stream, "%d : %s", &ncolor, c);
     for (n = 0; n < ncolor; n++)
-	fscanf(stream, "%6d%6d%6d : %s", &rx[n], &gx[n], &bx[n], c);
+	fscanf(stream, "%6ld%6ld%6ld : %s", &rx[n], &gx[n], &bx[n], c);
 
 /* read bitmap file */
 
@@ -209,11 +209,13 @@ void zxdcls_()
 
     KeySym key;
 
+    next = False;
+
     if (!wait && wait1) {
 	while (1) {
 	    XNextEvent (d, &e);
 	    if (e.type == KeyPress) {
-	        if (XLookupString (&e, string, 2, &key, NULL) == 1) {
+	        if (XLookupString (&e.xkey, string, 2, &key, NULL) == 1) {
 		    switch (key) {
 	            case XK_Return:
 			next = True;
@@ -267,18 +269,19 @@ void zxpcls_()
 
     XFlush (d);
     if (XCheckTypedEvent (d, KeyPress, &e)) {
-	ixl = XLookupString (&e, string, 2, &key, NULL);
+	ixl = XLookupString (&e.xkey, string, 2, &key, NULL);
 	if (key == XK_w)
 	    wait = True;
     }
 
     dumpz = False;
+    next = False;
 
     if (wait) {
 	while (1) {
 	    XNextEvent (d, &e);
 	    if (e.type == KeyPress) {
-	        if (XLookupString (&e, string, 2, &key, NULL) == 1) {
+	        if (XLookupString (&e.xkey, string, 2, &key, NULL) == 1) {
 		    switch (key) {
 	            case XK_Return:
 			next = True;
@@ -539,7 +542,7 @@ void zxqpnt_(wx, wy, mb)
     else {
 	*wx = e.xkey.x;
 	*wy = wsywd - e.xkey.y;
-	ixl = XLookupString (&e , cc, 1, 0, 0);
+	ixl = XLookupString (&e.xkey , cc, 1, 0, 0);
 	*mb = *cc;
     }
 }
