@@ -30,7 +30,7 @@
             CALL STFTR3(U3X(1), U3Y(1), U3Z(1), VX, VY, VZ)
             CALL SZPLL3(VX, VY, VZ)
           ELSE
-            CALL STFPR3(U3X(I), U3Y(I), U3Z(I), VX, VY, VZ)
+            CALL STFTR3(U3X(I), U3Y(I), U3Z(I), VX, VY, VZ)
             CALL SZMVL3(VX, VY, VZ)
             LFLAG=.TRUE.
           END IF
