@@ -1,5 +1,5 @@
 *-----------------------------------------------------------------------
-*     TEXT PRIMITIVE
+*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SZTXOP(RSIZE,IROTA,ICENT,INDEX)
 
@@ -7,7 +7,7 @@
 
       CHARACTER COBJ*80
 
-      COMMON    /SZBTX1/ IFONT,QSIZE,CT,ST,ICENTZ
+      COMMON    /SZBTX1/ QSIZE,CT,ST,ICENTZ
       COMMON    /SZBTX2/ LCNTL,JSUP,JSUB,JRST,SMALL,SHIFT
       LOGICAL   LCNTL
       COMMON    /SZBTX3/ LCLIP
@@ -16,7 +16,7 @@
       SAVE
 
 
-      CALL SGIGET('IFONT',IFONT)
+*     CALL SGIGET('IFONT',IFONT)
 
       QSIZE=RSIZE/WIDE
       THETA=RD2R(REAL(IROTA))
@@ -41,7 +41,8 @@
       CALL SZQIDX(INDEXZ)
       CALL SZSIDX(INDEX)
 
-      WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IFONT,IWS
+*     WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IFONT,IWS
+      WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IWS
       CALL CDBLK(COBJ)
       CALL SWOOPN('SZTX',COBJ)
 
