@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       INTEGER FUNCTION IUETON(ZLEV)
 
@@ -22,7 +24,7 @@
           GO TO 10
         END IF
       ELSE
-        DO 20 IT = MAXNT, 1, -1
+        DO 20 IT = NT, 1, -1
           IF (TL1(IT).LE.ZLEV .AND. ZLEV.LE.TL2(IT)) GO TO 30
    20   CONTINUE
    30   CONTINUE
