@@ -1,8 +1,11 @@
 *-----------------------------------------------------------------------
 *     UEGTLA
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UEGTLA(XMIN,XMAX,DX)
 
+      LOGICAL   LBOUND
       EXTERNAL  RGNGE,IRLE,IRGE
 
 
@@ -11,10 +14,10 @@
       END IF
 
       CALL UEIGET('NLEV    ',NLEV  )
-      CALL UEIGET('ICYCLE  ',ICYCL )
       CALL UEIGET('ITPAT   ',ITPAT )
       CALL UEIGET('ICOLOR1 ',ICLR1 )
       CALL UEIGET('ICOLOR2 ',ICLR2 )
+      CALL UELGET('LBOUND  ',LBOUND)
 
       IF (DX.GT.0) THEN
         DZ=DX
@@ -25,9 +28,8 @@
         DZ=RGNGE((XMAX-XMIN)/NL)
       END IF
 
-      DZC=DZ*ICYCL
-      ZMIN=IRLE(XMIN/DZC)*DZC
-      ZMAX=IRGE(XMAX/DZC)*DZC
+      ZMIN=IRLE(XMIN/DZ)*DZ
+      ZMAX=IRGE(XMAX/DZ)*DZ
       N=NINT((ZMAX-ZMIN)/DZ)
 
       CALL UEITLV
@@ -36,6 +38,9 @@
 
         TLEV1=DZ*NINT((ZMIN+(I-1)*DZ)/DZ)
         TLEV2=TLEV1+DZ
+        IF (LBOUND .AND. I.EQ.1) TLEV1=MAX(TLEV1,XMIN)
+        IF (LBOUND .AND. I.EQ.N) TLEV2=MIN(TLEV2,XMAX)
+
         IF (N.EQ.1) THEN
           IPAT=(ICLR2-ICLR1)/2*1000+ITPAT
         ELSE
