@@ -1,5 +1,7 @@
 *-----------------------------------------------------------------------
 *     UEGTLB
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UEGTLB(Z,MX,NX,NY,DX)
 
@@ -7,7 +9,7 @@
 
       INTEGER   NS(2),NP(2),NQ(2)
 
-      EXTERNAL  RVMIN,RVMAX,RGNGE,IRLE,IRGE
+      EXTERNAL  RVMIN,RVMAX,RGNGE
 
 
       CALL GLLGET('LMISS',LMISS)
@@ -33,9 +35,7 @@
         NL=MAX(1,NINT(ABS(DX)))
         DZ=RGNGE((XMAX-XMIN)/NL)
       END IF
-      ZMIN=IRLE(XMIN/DZ)*DZ
-      ZMAX=IRGE(XMAX/DZ)*DZ
 
-      CALL UEGTLA(ZMIN,ZMAX,DZ)
+      CALL UEGTLA(XMIN,XMAX,DZ)
 
       END
