@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE ULYLOG ( CSIDE, NLBL, NTICKS )
 
@@ -7,14 +9,11 @@
 
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UY1(MAXS),UY2(MAXL),UYT(MAXL)
-      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CYFMT*16,CSGI,CSIDE
-      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK
+      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CSGI,CSIDE
+      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK,LOFF
 
       SAVE
 
-      DATA CFMT/'B'/
-
-
       IF(.NOT.LUYCHK(CSIDE))
      #   CALL MSGDMP('E', 'ULYLOG', 'INVALID CSIDE.')
       IF(NLBL.LT.1 .OR. NLBL.GT.4)
@@ -22,7 +21,20 @@
       IF(NTICKS.LT.1 .OR. NTICKS.GT.9)
      #   CALL MSGDMP('E', 'ULYLOG', 'INVALID NTICKS.')
 
-      CALL SGQWND(UX1,UX2,YMIN,YMAX)
+      CALL SGQWND(UXMIN,UXMAX,UYMIN,UYMAX)
+
+      CALL UZLGET('LOFFSET', LOFF)
+      IF(LOFF) THEN
+        CALL UZRGET('YFACT',   FACTOR)
+        YMIN = UYMIN/FACTOR
+        YMAX = UYMAX/FACTOR
+        CALL SGSWND(UXMIN, UXMAX , YMIN, YMAX)
+        CALL SGSTRF
+      ELSE
+        YMIN = UYMIN
+        YMAX = UYMAX
+      ENDIF
+
       IF(YMIN.GT.YMAX)THEN
         YYY=YMIN
         YMIN=YMAX
@@ -104,6 +116,7 @@
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
           ELSE
+            CALL UZCGET('CYFMT', CFMT)
             CALL CHVAL(CFMT, UY2(NBL), CH(NBL))
             CALL CLADJ(CH(NBL))
           ENDIF
@@ -121,21 +134,9 @@
       CALL GLLSET('LEPSL',LEPSL)
       CALL GNRSET
 
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY ULYSFM ( CYFMT )
+      IF(LOFF) THEN
+        CALL SGSWND(UXMIN,UXMAX,UYMIN,UYMAX)
+        CALL SGSTRF
+      ENDIF
 
-*     SET FORMAT FOR IYTYPE=3 OR 4
-
-      CFMT=CYFMT
-
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY ULYQFM ( CYFMT )
-
-*     GET FORMAT FOR IYTYPE=3 OR 4
-
-      CYFMT=CFMT
-
-      RETURN
       END
