@@ -1,17 +1,14 @@
 *-----------------------------------------------------------------------
-*     USPACK DRAW X-AXIS                              S.Sakai  92/03/04
+*     USPACK DRAW X-AXIS                              DCL 5.0  95/09/04
 *-----------------------------------------------------------------------
 
       SUBROUTINE USXAXS(CSIDE)
-      CHARACTER  CSIDE*1, CFMT*8, CUNIT*32, CP*8
+      CHARACTER  CSIDE*1, CP*8
       LOGICAL    LMATCH
 
       IF(CSIDE.EQ.' ') RETURN
-      CALL USCGET('CXUNIT', CUNIT)
 
       CALL SGQTRN(ITR)
-      IF(ITR.GE.5) CALL MSGDMP('E', 'USXAXS',
-     #             'INVALID TRANSFORMATION NUMBER.')
       CALL SGQVPT(VXMIN, VXMAX, VYMIN, VYMAX)
       CALL SGQWND(UXMIN, UXMAX, UYMIN, UYMAX)
 
@@ -22,14 +19,14 @@
         MODE = MOD(IROTA,2)
         IF(LMATCH) MODE = 0
 
-        CALL USUSCU('X', UXMIN, UXMAX, VXMIN, VXMAX, MODE,
-     &                     DT, DL, CFMT, FAC, OFF)
-        CALL USXAXU(CSIDE, DT, DL, CFMT, FAC, OFF, CUNIT)
+        CALL USUSCU('X', UXMIN, UXMAX, VXMIN, VXMAX, MODE)
+        CALL USXAXU(CSIDE)
 
       ELSEIF(ITR.EQ.3 .OR. ITR.EQ.4) THEN
-        CALL USUSCL('X', UXMIN, UXMAX, VXMIN, VXMAX,
-     &                     NLBL, NTICK, ITYPE, FAC)
-        CALL USXAXL(CSIDE, NLBL, NTICK, ITYPE, FAC, CUNIT)
+        CALL USUSCL('X', UXMIN, UXMAX, VXMIN, VXMAX)
+        CALL USXAXL(CSIDE)
+      ELSE
+        CALL MSGDMP('E', 'USXAXS', 'INVALID TRANSFORMATION NUMBER.')
       ENDIF
 
       RETURN
