@@ -5,7 +5,7 @@
 
       PARAMETER (A = 1.4142136)
 
-      EXTERNAL  RFPI, XMPLON
+      EXTERNAL  XMPLON
 
 
       XLM2 = XMPLON(XLON)/2
